#

##

###

###

##

###

###

###

###

###

###

###

##

##

###

###

##

###

###

###

##

##

    	vegan

    	on
    		1st terminal panel
    			#
    			#	if there's a docker conflict
    			#
    			#
    			docker rm $(docker ps -a -q)

    			#
    			#	on
    			#
    			docker compose up -d; sleep 5; docker exec -it vegan.1 bash -c "source /habitat/_controls/source_2.sh && bash"

    			#
    			#	optional: install
    			#
    			#
    			python3 /habitat/_controls/install_with_uv.py

    			#
    			#	optional: if need to import the database
    			#
    			vegan_1 adventures monetary saves import --version 1 --drop

    		2+ terminal panels
    			docker exec -it vegan.1 bash -c "source /habitat/_controls/source_2.sh && bash"

    			#
    			#
    			#	build the front
    			#
    			(cd /habitat/venues/stages/vegan/adventures/vv_turbo/apps/web && bun run build --watch)

    	garages (harbors)
    		sanic
    			http://192.168.0.100:8000/docs/swagger#/

    		sanic inspector
    			http://192.168.0.100:7457

    		mongo
    			http://192.168.0.100:39000

    			node_data
    				/vegan/venues/stages/vegan/adventures/monetary/__monetary_1

    			saves
    				ls /vegan/venues/stages/vegan/adventures/monetary/__saves

    			saving
    				vegan_1 adventures monetary saves export --version 2

    			loading
    				vegan_1 adventures monetary saves import-overwrite --version 2

    	bun
    		apt install unzip; curl -fsSL https://bun.sh/install | bash; source /root/.bashrc

    		install
    			(cd /habitat/venues/stages/vegan/adventures/vv_turbo/ && bun install)

    		on
    			(cd /habitat/venues/stages/vegan/adventures/vv_turbo/ && bun run dev)
    			(cd /habitat/venues/stages/vegan/adventures/vv_turbo/apps/web && bun run build --watch)

    		previously
    			(cd /habitat/venues/stages/vegan/adventures && npx create-turbo@latest -e with-vite)
    			(cd /habitat/venues/stages/vegan/adventures/vv_turbo/ && bun add @vitejs/plugin-vue)
    			(cd /habitat/venues/stages/vegan/adventures/vv_turbo/apps/web && bun pm untrusted)

    	publishing
    		linting
    			(cd /vegan/venues/stages/vegan && pycycle --here)

    		status
    			cd /vegan/venues/stages/vegan/__status/main
    			python3 /habitat/venues/stages/vegan/__status/main/status.proc.py

    			#
    			#	external API checks
    			#
    			python3 /habitat/venues/stages/vegan/__status/API/status.proc.py

    			# vite status

    		publish
    			#
    			#	[ ] poetry auth
    			#
    			#
    			pip install poetry && cd /habitat && rm -rf dist && poetry build --verbose && poetry publish --verbose;
    			pip install poetry && cd /habitat && rm -rf dist && poetry build --format sdist --verbose && chmod -R 777 /habitat && poetry publish --verbose;

    	important
    		poetry show --tree

    	docker
    		docker compose up -d
    		docker exec -it vegan bash
    		docker exec -it vegan bash -c "source /vegan/moves/source_2.sh && bash"